==> haskell-wai-handler-launch-3.0.2.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.2
id: wai-handler-launch-3.0.2.2-4oaCII0tPHo3ynt6RxleJ9
key: wai-handler-launch-3.0.2.2-4oaCII0tPHo3ynt6RxleJ9
license: MIT
maintainer: michael@snoyman.com
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
abi: cf165d0fb4e31553df93484afa7219bf
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/wai-handler-launch-3.0.2.2
hs-libraries: HSwai-handler-launch-3.0.2.2-4oaCII0tPHo3ynt6RxleJ9
depends:
    async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ process-1.4.3.0
    streaming-commons-0.1.18-KZl1SWhWop6Ksa4IiFWi6P
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    warp-3.2.12-I48cwxl3zkoEHofxH09Q0X
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.2.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.2
id: wai-handler-launch-3.0.2.2-23mbCFsUCqk4TyV9ha2NS0
key: wai-handler-launch-3.0.2.2-23mbCFsUCqk4TyV9ha2NS0
license: MIT
maintainer: michael@snoyman.com
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
abi: 398af7733d72c6f50d22bf60fe8cf2e2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/wai-handler-launch-3.0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/wai-handler-launch-3.0.2.2
hs-libraries: HSwai-handler-launch-3.0.2.2-23mbCFsUCqk4TyV9ha2NS0
depends:
    async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ process-1.4.3.0
    streaming-commons-0.1.18-KZl1SWhWop6Ksa4IiFWi6P
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    warp-3.2.12-JHy0oausRdD30Fa4JNt43k
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
